From 6df1574b8beeb3f6838f1ba7096019e0fcea9083 Mon Sep 17 00:00:00 2001
From: Richard van der Hoff <richard@matrix.org>
Date: Fri, 16 Jun 2017 15:05:14 +0100
Subject: [PATCH] onLoadCompleted is now onTokenLoginCompleted

---
 src/vector/index.js       | 18 ++++++++----------
 test/app-tests/loading.js |  8 +++++---
 2 files changed, 13 insertions(+), 13 deletions(-)

diff --git a/src/vector/index.js b/src/vector/index.js
index 9f162051..da03327d 100644
--- a/src/vector/index.js
+++ b/src/vector/index.js
@@ -216,18 +216,16 @@ function getConfig() {
     return deferred.promise;
 }
 
-function onLoadCompleted() {
+function onTokenLoginCompleted() {
     // if we did a token login, we're now left with the token, hs and is
     // url as query params in the url; a little nasty but let's redirect to
     // clear them.
-    if (window.location.search) {
-        var parsedUrl = url.parse(window.location.href);
-        parsedUrl.search = "";
-        var formatted = url.format(parsedUrl);
-        console.log("Redirecting to " + formatted + " to drop loginToken " +
-                    "from queryparams");
-        window.location.href = formatted;
-    }
+    var parsedUrl = url.parse(window.location.href);
+    parsedUrl.search = "";
+    var formatted = url.format(parsedUrl);
+    console.log("Redirecting to " + formatted + " to drop loginToken " +
+                "from queryparams");
+    window.location.href = formatted;
 }
 
 async function loadApp() {
@@ -288,7 +286,7 @@ async function loadApp() {
                 realQueryParams={params}
                 startingFragmentQueryParams={fragparts.params}
                 enableGuest={true}
-                onLoadCompleted={onLoadCompleted}
+                onTokenLoginCompleted={onTokenLoginCompleted}
                 initialScreenAfterLogin={getScreenFromLocation(window.location)}
                 defaultDeviceDisplayName={PlatformPeg.get().getDefaultDeviceDisplayName()}
             />,
diff --git a/test/app-tests/loading.js b/test/app-tests/loading.js
index a323a262..04c68377 100644
--- a/test/app-tests/loading.js
+++ b/test/app-tests/loading.js
@@ -47,7 +47,7 @@ describe('loading:', function () {
     // the mounted MatrixChat
     let matrixChat;
 
     // a promise which resolves when the MatrixChat calls onLoadCompleted
     let loadCompletePromise;
 
     beforeEach(function() {
@@ -135,7 +135,7 @@ describe('loading:', function () {
                 realQueryParams={params}
                 startingFragmentQueryParams={fragParts.params}
                 enableGuest={true}
-                onLoadCompleted={loadCompleteDefer.resolve}
+                onTokenLoginCompleted={loadCompleteDefer.resolve}
                 initialScreenAfterLogin={getScreenFromLocation(windowLocation)}
                 makeRegistrationUrl={() => {throw new Error('Not implemented');}}
             />, parentDiv
@@ -360,6 +360,8 @@ describe('loading:', function () {
                 loadApp({
                     uriFragment: "#/login",
                 });
+
+                return q.delay(1);
             });
 
             it('shows a login view', function() {
@@ -513,7 +515,7 @@ describe('loading:', function () {
 
                 return httpBackend.flush();
             }).then(() => {
                 // at this point, MatrixChat should fire onLoadCompleted, which
                 // makes index.js reload the app. We're not going to attempt to
                 // simulate the reload - just check that things are left in the
                 // right state for the reloaded app.
@@ -47,7 +47,7 @@ describe('loading:', function () {
     let matrixChat;
 
-    // a promise which resolves when the MatrixChat calls onLoadCompleted
+    // a promise which resolves when the MatrixChat calls onTokenLoginCompleted
     let loadCompletePromise;
 
@@ -513,7 +515,7 @@ describe('loading:', function () {
                 return httpBackend.flush();
             }).then(() => {
-                // at this point, MatrixChat should fire onLoadCompleted, which
+                // at this point, MatrixChat should fire onTokenLoginCompleted, which
                 // makes index.js reload the app. We're not going to attempt to
                 // simulate the reload - just check that things are left in the